summaryrefslogtreecommitdiff
path: root/src/termhooks.h
diff options
context:
space:
mode:
authorGerd Moellmann <gerd@gnu.org>1999-09-05 15:49:07 +0000
committerGerd Moellmann <gerd@gnu.org>1999-09-05 15:49:07 +0000
commit9ea173e83025644384bad4a4ea697bcb6cf7995e (patch)
treef787c96d61d0fecd60d18e050f8649b6fd77a19d /src/termhooks.h
parente037b9ecb3c11b1775171da6e9376a5221fefd78 (diff)
downloademacs-9ea173e83025644384bad4a4ea697bcb6cf7995e.tar.gz
Change spelling of `toolbar' to `tool_bar' or `tool-bar'.
Likewise for upper-case etc.
Diffstat (limited to 'src/termhooks.h')
-rw-r--r--src/termhooks.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/termhooks.h b/src/termhooks.h
index 3f7fcd5bc4f..3cbc6dc2c05 100644
--- a/src/termhooks.h
+++ b/src/termhooks.h
@@ -307,13 +307,13 @@ enum event_kind
.code is a number identifying it,
index into lispy_user_signals. */
/* Currently only returned when the mouse enters a toolbar item that
has a help string. Member frame_or_window of the input_event is
- a cons cell whose car is the toolbar's frame and whose cdr is the
+ a cons cell whose car is the tool-bar's frame and whose cdr is the
help string. */
HELP_EVENT,
- TOOLBAR_EVENT
+ TOOL_BAR_EVENT
};
/* If a struct input_event has a kind which is selection_request_event
@@ -307,13 +307,13 @@ enum event_kind
.code is a number identifying it,
index into lispy_user_signals. */
- /* Currently only returned when the mouse enters a toolbar item that
+ /* Currently only returned when the mouse enters a tool-bar item that
has a help string. Member frame_or_window of the input_event is